pub struct AdminRegistry { /* private fields */ }Expand description
Registry of all admin resources.
Implementations
Sourceimpl AdminRegistry
impl AdminRegistry
Sourcepub fn register<R: AdminResource>(&mut self, resource: R)
pub fn register<R: AdminResource>(&mut self, resource: R)
Register a resource. Panics if a resource with the same slug already exists.
Sourcepub fn all(&self) -> Vec<Arc<dyn AdminResource>>
pub fn all(&self) -> Vec<Arc<dyn AdminResource>>
Get all registered resources in the order they were registered.