Module resource

Module resource 

Structs

AdminPrefix
Newtype for the admin site prefix to avoid Data collisions.
AdminTitle
Newtype for the admin site title to avoid Data collisions.
ResourceInfo
Information about a resource for serialization (e.g. for Tera templates).

Traits

AdminResource
Trait to be implemented by any resource that should be managed by the admin backoffice.